PRESENTATION := final_presentation
PRESENTATIONDIAGRAMS := data/presentationdiagrams
REPORT := report
DIAGRAMS := data/diagrams
LATEX = TEXINPUTS=$(d):$(b): pdflatex -halt-on-error -interaction=nonstopmode \
	-output-directory $(@D) -shell-escape
REF_WARNING := "Rerun to get cross-references right"

.PHONY: docs bibclean upload

docs: $(b)$(REPORT).pdf $(b)proposal.pdf $(b)presentation.pdf \
	$(b)$(PRESENTATION).pdf

$(b)%.pdf: $(d)%.tex
	mkdir -p $(@D)
	$(LATEX) $^
	@while grep $(REF_WARNING) $(@:.pdf=.log) > /dev/null; do \
		echo "** Rerunning pdflatex for cross-references **"; \
		$(LATEX) $^; \
	done

$(b)$(PRESENTATION).pdf: $(d)$(PRESENTATIONDIAGRAMS).tex

$(b)$(REPORT).pdf: $(d)$(DIAGRAMS).tex $(b)$(REPORT).bbl

$(b)$(REPORT).bbl: $(d)$(REPORT).bib
	mkdir -p $(@D)
	$(LATEX) $(^:.bib=.tex)
	BIBINPUTS=$(d) bibtex8 $(@:.bbl=.aux)
	$(LATEX) $(^:.bib=.tex)
	$(LATEX) $(^:.bib=.tex)

upload: $(b)upload_$(REPORT) $(b)upload_$(PRESENTATION)

$(b)upload_$(PRESENTATION): $(b)$(PRESENTATION).pdf
	scp $^ mv:tk.nl && touch $@

$(b)upload_$(REPORT): $(b)$(REPORT).pdf
	scp $^ mv:tk.nl && touch $@

bibclean:
	rm -f $(d)report.bib~*
